@@ -12,7 +12,7 @@ use crate::{
     Cancel, NodeMessage, ShutdownType,
 };
 use core::time::Duration;
-use ockam_core::compat::{sync::Arc, vec::Vec};
+use ockam_core::compat::{string::String, sync::Arc, vec::Vec};
 use ockam_core::{
     Address, AddressSet, LocalMessage, Message, Processor, Result, Route, TransportMessage, Worker,
 };
@@ -316,7 +316,7 @@ impl Context {
         M: Message + Send + 'static,
     {
         if !self.address.as_ref().contains(&sending_address) {
-            return Err(Error::SenderAddressDoesntExist.into());
+            return Err(Error::SenderAddressDoesNotExist.into());
         }
 
         let (reply_tx, mut reply_rx) = channel(1);
