@@ -30,24 +30,24 @@ pub use ockam_executor::tokio;
 #[cfg(feature = "std")]
 pub use tokio;
 
-mod address_record;
+mod cancel;
 mod context;
 mod error;
 mod executor;
 mod handle;
-mod mailbox;
 mod messages;
 mod node;
 mod parser;
 mod relay;
 mod router;
+
+#[cfg(test)]
 mod tests;
 
-pub(crate) use address_record::*;
+pub use cancel::*;
 pub use context::*;
 pub use executor::*;
 pub use handle::*;
-pub use mailbox::*;
 pub use messages::*;
 
 pub use node::{start_node, NullWorker};
