@@ -18,6 +18,8 @@ where
         Self { processor, ctx }
     }
 
+    #[cfg_attr(not(feature = "std"), allow(unused_mut))]
+    #[cfg_attr(not(feature = "std"), allow(unused_variables))]
     async fn run(self, mut ctrl_rx: Receiver<CtrlSignal>) {
         let mut ctx = self.ctx;
         let mut processor = self.processor;
@@ -46,16 +48,25 @@ where
             Result::<()>::Ok(())
         };
 
-        // This future resolves when a stop control signal is received
-        let shutdown_signal = async { ctrl_rx.recv().await };
-
-        // Then select over the two futures
         #[cfg(feature = "std")]
-        tokio::select! {
-            _ = shutdown_signal => {
-                info!("Shutting down processor {}", ctx_addr);
-            },
-            _ = run_loop => {}
+        {
+            // This future resolves when a stop control signal is received
+            let shutdown_signal = async { ctrl_rx.recv().await };
+
+            // Then select over the two futures
+            tokio::select! {
+                _ = shutdown_signal => {
+                    info!("Shutting down processor {}", ctx_addr);
+                },
+                _ = run_loop => {}
+            };
+        }
+
+        // TODO wait on run_loop until we have a no_std select! implementation
+        #[cfg(not(feature = "std"))]
+        match run_loop.await {
+            Ok(_) => trace!("Processor shut down cleanly {}", ctx_addr),
+            Err(err) => error!("processor run loop aborted with error: {:?}", err),
         };
 
         // If we reach this point the router has signalled us to shut down
